function x = damassc(y, posN, micN, L, fs)
% The function impements a deconvolution aproach for the mapping of
% acoustic sources with a sparsity constraint, as proposed by Yardibi et al
% in there article. y contains the received signal from each microphone in
% the measurement array. The array consist of micN, and the acoustic
% mapping is performed over posN number og points. L gives half the size of
% a segement. fs is the sampling frequency. The A matrix and stearing
% vectors are saved in advance and loaded in for the calculation.

Ylength = length(y);        %length of received signal
I=floor(Ylength/(2*L));     %number of segments
df=fs/(2*L);                %frequency bin size
%% preprosessing the signal, splitting in segments and fft.
Yi = zeros(micN, I, L);
for m = 1:micN
    for k = 1:I
        temp=(fft(y(m,((k-1)*2*L+1):(k*2*L)))/(2*L));
        Yi(m,k,:)=temp(1:L);
    end
end

%% steering vector loading
s=load('Amatrix.mat');
A=s.A;
aX=s.aX;

%% computing the autocorrolation R and diagonal removal

R= zeros(micN, micN,L);

for l=1:L
    for k = 1:I
        R(:,:,l)=R(:,:,l)+Yi(:,k,l)*Yi(:,k,l)';
    end
end
R=(1/I)*R;
R=R*df;
R0=R;
for m = 1:micN
    R0(m,m,:)=0;        %diagonal removal of R
end

%% estimating user parameter

lamda=zeros(1,L);
for l=1:L
    [~,G]=eigs(R(:,:,l));
    ident=eye(length(G));
    lamda(l)=trace(G-(ident*G(end,end)));
end

%% minimizing and estimating x

Y=zeros(posN,L);
for n=1:posN                    % for measurement position
    for l=1:L                   % for frequency
            Y(n,l)=aX(:,n,l)'*R0(:,:,l)*aX(:,n,l);
    end
end
Y=(1/(micN^2-micN))*Y;          % DAS beamformer output
x=zeros(posN,L);
x0=zeros(posN,1);
B=ones(1,posN);
options=optimset('Algorithm','interior-point', 'MaxFunEvals', 10000);


for l=1:L
    x(:,l)=fmincon(@(t)normsq(Y(:,l), A(:,:,l), t),abs(Y(:,l)),B,lamda(l),[],[],x0,lamda(l)*B,[],options);
end

end